==> 0q0-roblox-1.4.6.tgz: package/lib/catalog/searchCatalog.js <==
// Includes
var http = require('../util/http.js').func;

// Args
exports.required = [];
exports.optional = ['geartype', 'genre', 'category', 'subcategory', 'currency', 'sort', 'freq', 'keyword', 'creatorID', 'minim', 'maxim', 'notforsale', 'pagenumber', 'resultsperpage'];

// Define
function searchCatalog(geartype, genre, category, subcategory, currency, sort, freq, keyword, creatorID, minim, maxim, notforsale, pagenumber, resultsperpage) {
  var url = "//search.roblox.com/catalog/json?";

  if (geartype) url += "Gears=" + geartype;
  if (genre) url += "&Genres=" + genre;
  if (category) url += "&Category=" + category;
  if (subcategory) url += "&Subcategory=" + subcategory;
  if (currency) url += "&CurrencyType=" + currency;
  if (sort) url += "&SortType=" + sort;
  if (freq) url += "&AggregationFrequency=" + freq;
  if (keyword) url += "&Keyword=" + keyword;
  if (creatorID) url += "&CreatorID=" + creatorID;
  if (minim) url += "&PxMin=" + minim;
  if (maxim) url += "&PxMax=" + maxim;
  if (notforsale) { url += "&IncludeNotForSale=true"; } else { url += "&IncludeNotForSale=false" }
  if (pagenumber) url += "&PageNumber=" + pagenumber;
  if (resultsperpage) url += "&ResultsPerPage=" + resultsperpage;

  var httpOpt = {
    url: url,
    options: {
      resolveWithFullResponse: true,
      method: 'GET'
    }
  };

  return http(httpOpt)
  .then(function (res) {
    if (res.statusCode === 200) {
      return JSON.parse(res.body);
    } else {
      throw new Error("Couldn't fetch catalog!");
    }
  });
}

exports.func = function (args) {
  var geartype = args.geartype;
  var genre = args.genre;
  var category = args.category;
  var subcategory = args.subcategory;
  var currency = args.currency;
  var sort = args.sort;
  var freq = args.freq;
  var keyword = args.keyword;
  var creatorID = args.creatorID;
  var minim = args.minim;
  var maxim = args.maxim;
  var notforsale = args.notforsale;
  var pagenumber = args.pagenumber;
  var resultsperpage = args.resultsperpage;
  return searchCatalog(geartype, genre, category, subcategory, currency, sort, freq, keyword, creatorID, minim, maxim, notforsale, pagenumber, resultsperpage);
};

==> 0q0-roblox-1.5.6.tgz: package/lib/catalog/searchCatalog.js <==
var http = require('../util/http.js').func;

exports.required = [];
exports.optional = ['geartype', 'genre', 'category', 'subcategory', 'currency', 'sort', 'freq', 'keyword', 'creatorID', 'minim', 'maxim', 'notforsale', 'pagenumber', 'resultsperpage'];

function searchCatalog(geartype, genre, category, subcategory, currency, sort, freq, keyword, creatorID, minim, maxim, notforsale, pagenumber, resultsperpage) {
  var url = "//search.roblox.com/catalog/json?";

  if (geartype) url += "&Gears=" + geartype;
  if (genre) url += "&Genres=" + genre;
  if (category) url += "&Category=" + category;
  if (subcategory) url += "&Subcategory=" + subcategory;
  if (currency) url += "&CurrencyType=" + currency;
  if (sort) url += "&SortType=" + sort;
  if (freq) url += "&AggregationFrequency=" + freq;
  if (keyword) url += "&Keyword=" + keyword;
  if (creatorID) url += "&CreatorID=" + creatorID;
  if (minim) url += "&PxMin=" + minim;
  if (maxim) url += "&PxMax=" + maxim;
  if (notforsale) { url += "&IncludeNotForSale=true"; } else { url += "&IncludeNotForSale=false" }
  if (pagenumber) url += "&PageNumber=" + pagenumber;
  if (resultsperpage) url += "&ResultsPerPage=" + resultsperpage;

  var httpOpt = {
    url: url,
    options: {
      resolveWithFullResponse: true,
      method: 'GET'
    }
  };

  return http(httpOpt)
  .then(function (res) {
    if (res.statusCode === 200) {
      return JSON.parse(res.body);
    } else {
      throw new Error("Couldn't fetch catalog!");
    }
  });
}

exports.func = function (args) {
  var geartype = args.geartype;
  var genre = args.genre;
  var category = args.category;
  var subcategory = args.subcategory;
  var currency = args.currency;
  var sort = args.sort;
  var freq = args.freq;
  var keyword = args.keyword;
  var creatorID = args.creatorID;
  var minim = args.minim;
  var maxim = args.maxim;
  var notforsale = args.notforsale;
  var pagenumber = args.pagenumber;
  var resultsperpage = args.resultsperpage;
  return searchCatalog(geartype, genre, category, subcategory, currency, sort, freq, keyword, creatorID, minim, maxim, notforsale, pagenumber, resultsperpage);
};
